import setuptools



setuptools.setup(
    name="getacs5ydata",
    version="1.0.0",
    author="Will Armstrong",
    author_email="williamqarmstrong@gmail.com",
    description="Gets ACS 5 Y Data",
    long_description="Gets ACS 5 Y Data",
    long_description_content_type="text/markdown",
    url="https://github.com/username/getacs5ydata",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ),
)